Method: SimpleOracleJDBC::OraArray#initialize

Defined in:
lib/simple_oracle_jdbc/ora_array.rb

#initialize(ora_type, values) ⇒ OraArray

This must be initialized with the name of the Oracle array type as defined on the database, ie the t_name is table of varchar2(10);

Values must be an array of Ruby objects, or nil. The values in the array will be cast into the appropriate Oracle type depending on the definition of the array defined in Oracle.



14
15
16
17
18
# File 'lib/simple_oracle_jdbc/ora_array.rb', line 14

def initialize(ora_type, values)
  @ora_type   = ora_type.upcase
  self.values = values
  @descriptor = nil
end